==> wordpress_0.5.4.orig.tar.gz: wordpress-0.5.4.orig/src/collectionlist.cpp <==
#include "collectionlist.h"
#include "BlogView.h"
#include "textlistitem.h"
#include "PopupMenu.h"
#include "wpscrollarea.h"

CollectionList::CollectionList(QWidget *parent, WPScrollArea* aScrollArea)
	: QWidget(parent), iScrollArea(aScrollArea), iStretchCount(0)
{
	ui.setupUi(this);
	iActionOpen = new QAction(tr("Open"), this);
	iActionEdit = new QAction(tr("Edit"), this);
	iActionDelete = new QAction(tr("Delete"), this);
	iPopupMenu = NULL;
	ui.titleLabel->setTextFormat(Qt::RichText);
}

void CollectionList::SetTitle(QString aTitle, bool aCanHaveFocus)
{
	iTitle = aTitle;
	ui.titleLabel->setText(iTitle);
	if (aCanHaveFocus)
		ui.titleLabel->setFocusPolicy(Qt::StrongFocus);
}

void CollectionList::AddCustomItem(const QString aItemId, QString aTitle, QString aFrom, QStringList aDetails)
{
	TextListItem * listItem = new TextListItem(aItemId, aTitle, aFrom,aDetails, this);
	connect(listItem, SIGNAL(TextListItemSelected(TextListItem*)), this, SLOT(ShowContextMenu(TextListItem*)));
	ui.itemLayout->addWidget(listItem);
}

void CollectionList::RemoveItem(QWidget* aItem)
{
	QLayoutItem* item;
	const int count = ui.itemLayout->count();
	for (int i = 0; i < count; i++)
	{
		item = ui.itemLayout->itemAt(i);
		if (item->widget() == aItem)
		{
			item = ui.itemLayout->takeAt(i);
			item->widget()->deleteLater();
			delete item;
			SetTitle();
			ui.itemLayout->invalidate();
			return;
		}
	}
}

void CollectionList::ResetList()
{
	iStretchCount = 0;
	QLayoutItem* item;
	while (item = ui.itemLayout->takeAt(0))
	{
		delete item->widget();
		delete item;
	}
	ui.itemLayout->invalidate();
}

CollectionList::~CollectionList()
{
}

void CollectionList::DisableMenuAction(CollectionList::TMenuAction aAction)
{
	if (!iDisabledActions.contains(aAction))
		iDisabledActions.append(aAction);
}

void CollectionList::ShowContextMenu(TextListItem* aItem)
{
	if (iScrollArea->IsDragging() || iPopupMenu)
		return;
	
	iPopupMenu = new PopupMenu(this);
	connect(iPopupMenu, SIGNAL(aboutToHide()), this, SLOT(MenuHiding()));
    iScrollArea->DisableScrollAtWidget(iPopupMenu);
	iCurrentItem = aItem;
	
	// Check if some item is disabled in the menu
	if (!iDisabledActions.contains(EOpen))
	    iPopupMenu->addAction(iActionOpen);
	if (!iDisabledActions.contains(EEdit))
	    iPopupMenu->addAction(iActionEdit);
	if (!iDisabledActions.contains(EDelete))
	    iPopupMenu->addAction(iActionDelete);

	QPoint itemPoint = aItem->TopRight();
	itemPoint.setY(itemPoint.y() - 5);
	QPoint globalItemPoint = mapToGlobal(itemPoint);
	QSize size = iPopupMenu->sizeHint();
	// Set popup a couple of pixels away from the screen right edge
	itemPoint.setX(itemPoint.x() - size.width() + 22); 
	// Make sure the popup won't be placed over the tab bar
	if (globalItemPoint.y() < iScrollArea->TopRightInGlobal().y())
	{
		itemPoint.setY(itemPoint.y() - globalItemPoint.y() + iScrollArea->TopRightInGlobal().y());	
	}
	if (!iDisabledActions.contains(EOpen))
		iPopupMenu->setActiveAction(iActionOpen);
	else if (!iDisabledActions.contains(EEdit))
		iPopupMenu->setActiveAction(iActionEdit);
	else if (!iDisabledActions.contains(EDelete))
		iPopupMenu->setActiveAction(iActionDelete);
	iPopupMenu->setFocus();
	iPopupMenu->popup(mapToGlobal(itemPoint));
}

void CollectionList::SetTitle()
{
	QString title(iTitle);
	title += "(";
	title += QString::number(ui.itemLayout->count() - iStretchCount);
	title += ")";
	ui.titleLabel->setText(title);
}

void CollectionList::AddStretch()
{
	iStretchCount++;
	ui.itemLayout->addStretch();
}

void CollectionList::setFocus()
{
	// Set focus to the first list item, or to the title if there's no list items in the layout
	QLayoutItem *item = ui.itemLayout->itemAt(0);
	if (item)
	{
		QWidget *widgetItem = item->widget();
		if (widgetItem)
		{
			widgetItem->setFocus();
		}
	}
}

void CollectionList::MenuHiding()
{
    iScrollArea->RemoveSelfScrollingWidget(iPopupMenu);
    iPopupMenu->deleteLater();
    iPopupMenu = NULL;
}

int CollectionList::ItemCount() const
{
    return ui.itemLayout->count() - iStretchCount;
}

==> wordpress_0.6.0.orig.tar.gz: wordpress-0.6.0.orig/src/collectionlist.cpp <==
#include "collectionlist.h"
#include "BlogView.h"
#include "textlistitem.h"
#include "PopupMenu.h"
#include "wpscrollarea.h"

CollectionList::CollectionList(QWidget *parent, WPScrollArea& aScrollArea)
	: QWidget(parent), iScrollArea(aScrollArea), iStretchCount(0)
{
	ui.setupUi(this);
	iActionOpen = new QAction(tr("Open"), this);
	iActionEdit = new QAction(tr("Edit"), this);
	iActionDelete = new QAction(tr("Delete"), this);
	iPopupMenu = NULL;
	ui.titleLabel->setTextFormat(Qt::RichText);
}

void CollectionList::SetTitle(QString aTitle, bool aCanHaveFocus)
{
	iTitle = aTitle;
	ui.titleLabel->setText(iTitle);
	if (aCanHaveFocus)
		ui.titleLabel->setFocusPolicy(Qt::StrongFocus);
}

void CollectionList::AddCustomItem(const QString aItemId, QString aTitle, QString aFrom, QStringList aDetails)
{
	TextListItem * listItem = new TextListItem(aItemId, aTitle, aFrom,aDetails, this);
	connect(listItem, SIGNAL(TextListItemSelected(TextListItem*)), this, SLOT(ShowContextMenu(TextListItem*)));
	ui.itemLayout->addWidget(listItem);
}

void CollectionList::RemoveItem(QWidget* aItem)
{
	QLayoutItem* item;
	const int count = ui.itemLayout->count();
	for (int i = 0; i < count; i++)
	{
		item = ui.itemLayout->itemAt(i);
		if (item->widget() == aItem)
		{
			item = ui.itemLayout->takeAt(i);
			item->widget()->deleteLater();
			delete item;
			SetTitle();
			ui.itemLayout->invalidate();
			return;
		}
	}
}

void CollectionList::ResetList()
{
	iStretchCount = 0;
	QLayoutItem* item;
	while (item = ui.itemLayout->takeAt(0))
	{
		delete item->widget();
		delete item;
	}
	ui.itemLayout->invalidate();
}

CollectionList::~CollectionList()
{
}

void CollectionList::DisableMenuAction(CollectionList::TMenuAction aAction)
{
	if (!iDisabledActions.contains(aAction))
		iDisabledActions.append(aAction);
}

void CollectionList::ShowContextMenu(TextListItem* aItem)
{
	if (iScrollArea.IsDragging() || iPopupMenu)
		return;
	
	iPopupMenu = new PopupMenu(this);
	connect(iPopupMenu, SIGNAL(aboutToHide()), this, SLOT(MenuHiding()));
    iScrollArea.DisableScrollAtWidget(iPopupMenu);
	iCurrentItem = aItem;
	
	// Check if some item is disabled in the menu
	if (!iDisabledActions.contains(EOpen))
	    iPopupMenu->addAction(iActionOpen);
	if (!iDisabledActions.contains(EEdit))
	    iPopupMenu->addAction(iActionEdit);
	if (!iDisabledActions.contains(EDelete))
	    iPopupMenu->addAction(iActionDelete);

	QPoint itemPoint = aItem->TopRight();
	/*itemPoint.setY(itemPoint.y() - 5);
	QPoint globalItemPoint = mapToGlobal(itemPoint);
	QSize size = iPopupMenu->sizeHint();
	// Set popup a couple of pixels away from the screen right edge
	itemPoint.setX(itemPoint.x() - size.width() + 22); 
	// Make sure the popup won't be placed over the tab bar
	if (globalItemPoint.y() < iScrollArea.TopRightInGlobal().y())
	{
		itemPoint.setY(itemPoint.y() - globalItemPoint.y() + iScrollArea.TopRightInGlobal().y());	
	}*/
	if (!iDisabledActions.contains(EOpen))
		iPopupMenu->setActiveAction(iActionOpen);
	else if (!iDisabledActions.contains(EEdit))
		iPopupMenu->setActiveAction(iActionEdit);
	else if (!iDisabledActions.contains(EDelete))
		iPopupMenu->setActiveAction(iActionDelete);
	iPopupMenu->setFocus();
	iPopupMenu->popup(getMenuLocation(itemPoint));
}

void CollectionList::SetTitle()
{
	QString title(iTitle);
	title += '(';
	title += QString::number(ui.itemLayout->count() - iStretchCount);
	title += ')';
	ui.titleLabel->setText(title);
}

void CollectionList::AddStretch()
{
	iStretchCount++;
	ui.itemLayout->addStretch();
}

void CollectionList::setFocus()
{
	// Set focus to the first list item, or to the title if there's no list items in the layout
	QLayoutItem *item = ui.itemLayout->itemAt(0);
	if (item)
	{
		QWidget *widgetItem = item->widget();
		if (widgetItem)
		{
			widgetItem->setFocus();
		}
	}
}

void CollectionList::MenuHiding()
{
    iScrollArea.RemoveSelfScrollingWidget(iPopupMenu);
    iPopupMenu->deleteLater();
    iPopupMenu = NULL;
}

int CollectionList::ItemCount() const
{
    return ui.itemLayout->count() - iStretchCount;
}

void CollectionList::resizeEvent(QResizeEvent* event) {
	Q_UNUSED(event);
	
	if (iPopupMenu != NULL && iPopupMenu->isVisible())
		iPopupMenu->move(getMenuLocation(iCurrentItem->TopRight()));
}

QPoint CollectionList::getMenuLocation(QPoint itemPoint) {
	itemPoint.setY(itemPoint.y() - 5);
	QPoint globalItemPoint = mapToGlobal(itemPoint);
	QSize size = iPopupMenu->sizeHint();
	// Set popup a couple of pixels away from the screen right edge
	itemPoint.setX(itemPoint.x() - size.width() + 22); 
	// Make sure the popup won't be placed over the tab bar
	if (globalItemPoint.y() < iScrollArea.TopRightInGlobal().y())
	{
		itemPoint.setY(itemPoint.y() - globalItemPoint.y() + iScrollArea.TopRightInGlobal().y());	
	}
	return mapToGlobal(itemPoint);
}
